/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef _LOG4CXX_TESTS_UTIL_SERIALIZATIONTESTHELPER_H
#define _LOG4CXX_TESTS_UTIL_SERIALIZATIONTESTHELPER_H

#include <log4cxx/spi/loggingevent.h>

namespace log4cxx
{
namespace util
{
class SerializationTestHelper
{
	public:
		static bool compare(const char* filename,
			const log4cxx::spi::LoggingEventPtr& event,
			size_t stopCompare);
		static bool compare(const char* filename,
			const std::vector<unsigned char>& array,
			size_t stopCompare, log4cxx::helpers::Pool& p);
	private:
		SerializationTestHelper();
		SerializationTestHelper(const SerializationTestHelper&);
		SerializationTestHelper& operator=(SerializationTestHelper&);
};
}
}

#endif
